@@ -590,29 +590,16 @@ def swap_code():
 
 @task
 def rollback_code():
-#    with settings(hide('warnings'), warn_only=True):
-#        sudo('unlink /data/deploy/current')
-#        sudo('unlink /data/deploy/pending')
+    with settings(hide('warnings'), warn_only=True):
+        sudo('unlink /data/deploy/current')
+        sudo('unlink /data/deploy/pending')
 
-    with settings(shell_escape=True, warn_only=True):
-        t=run('(ls -t|grep 20|head -2|ls|grep 20)|sort -r|head -2|tail -1|xargs -I % sudo ln -s /data/deploy/% /data/deploy/current')
-        logger.info("real: %s",t.real_command)
-        logger.info("cmd:  %s",t.command)  
-        logger.info("stderr: %s",t.stderr)
-        logger.info("return_code: %s", t.return_code)
-        logger.info("out: %s",t)
+    with cd("/data/deploy/"):
 
-        t=run('ls -al /data/deploy/')
-        logger.info("real: %s",t.real_command)
-        logger.info("cmd:  %s",t.command)  
+        run('(ls -t|grep 20|head -2|ls|grep 20)|sort -r|head -2|tail -1|xargs -I % sudo ln -s /data/deploy/% /data/deploy/current')
+        run("(ls -t|grep 20|head -2|ls|grep 20)|sort -r|head -2|tail -1|xargs -I \\% sudo ln -s /data/deploy/\\% /data/deploy/pending")
 
-#        t=run("ls -t|grep 20|head -2|ls|grep 20|sort -r|head -2|tail -1|xargs -I \\% sudo ln -s /data/deploy/\\% /data/deploy/pending")
-#        logger.info("real: %s",t.real_command)
-#        logger.info("cmd:  %s",t.command)  
-
-#       t=run("ls -t|grep 20|head -2|ls|grep 20|sort -r|head -1 |xargs -I \\% sudo rm -rf \\%")  
-#        logger.info("real: %s",t.real_command)
-#        logger.info("cmd:  %s",t.command)  
+#        run("ls -t|grep 20|head -2|ls|grep 20|sort -r|head -1 |xargs -I \\% sudo rm -rf \\%")  
 
 
 @task
